@@ -11,7 +11,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -29,8 +29,6 @@
 
 namespace QuantLib {
 
-    QL_DEPRECATED_DISABLE_WARNING
-
     CPICoupon::CPICoupon(Real baseCPI,
                          const Date& paymentDate,
                          Real nominal,
@@ -44,9 +42,9 @@ namespace QuantLib {
                          const Date& refPeriodStart,
                          const Date& refPeriodEnd,
                          const Date& exCouponDate)
-    : CPICoupon(baseCPI, paymentDate, nominal, startDate, endDate, index,
-                observationLag, observationInterpolation, dayCounter,
-                fixedRate, 0.0, refPeriodStart, refPeriodEnd, exCouponDate) {}
+    : CPICoupon(baseCPI, Date(), paymentDate, nominal, startDate, endDate,
+                index, observationLag, observationInterpolation, dayCounter,
+                fixedRate, refPeriodStart, refPeriodEnd, exCouponDate) {}
 
     CPICoupon::CPICoupon(const Date& baseDate,
                          const Date& paymentDate,
@@ -61,9 +59,9 @@ namespace QuantLib {
                          const Date& refPeriodStart,
                          const Date& refPeriodEnd,
                          const Date& exCouponDate)
-    : CPICoupon(baseDate, paymentDate, nominal, startDate, endDate, index,
-                observationLag, observationInterpolation, dayCounter,
-                fixedRate, 0.0, refPeriodStart, refPeriodEnd, exCouponDate) {}
+    : CPICoupon(Null<Real>(), baseDate, paymentDate, nominal, startDate, endDate,
+                index, observationLag, observationInterpolation, dayCounter,
+                fixedRate, refPeriodStart, refPeriodEnd, exCouponDate) {}
 
     CPICoupon::CPICoupon(Real baseCPI,
                          const Date& baseDate,
@@ -79,77 +77,19 @@ namespace QuantLib {
                          const Date& refPeriodStart,
                          const Date& refPeriodEnd,
                          const Date& exCouponDate)
-    : CPICoupon(baseCPI, baseDate, paymentDate, nominal, startDate, endDate, index,
-                observationLag, observationInterpolation, dayCounter,
-                fixedRate, 0.0, refPeriodStart, refPeriodEnd, exCouponDate) {}
-
-    CPICoupon::CPICoupon(Real baseCPI,
-                         const Date& paymentDate,
-                         Real nominal,
-                         const Date& startDate,
-                         const Date& endDate,
-                         const ext::shared_ptr<ZeroInflationIndex>& index,
-                         const Period& observationLag,
-                         CPI::InterpolationType observationInterpolation,
-                         const DayCounter& dayCounter,
-                         Real fixedRate,
-                         Spread spread,
-                         const Date& refPeriodStart,
-                         const Date& refPeriodEnd,
-                         const Date& exCouponDate)
-    : CPICoupon(baseCPI, Null<Date>(), paymentDate, nominal, startDate, endDate, index,
-                observationLag, observationInterpolation, dayCounter,
-                fixedRate, spread, refPeriodStart, refPeriodEnd, exCouponDate) {}
-
-    CPICoupon::CPICoupon(const Date& baseDate,
-                         const Date& paymentDate,
-                         Real nominal,
-                         const Date& startDate,
-                         const Date& endDate,
-                         const ext::shared_ptr<ZeroInflationIndex>& index,
-                         const Period& observationLag,
-                         CPI::InterpolationType observationInterpolation,
-                         const DayCounter& dayCounter,
-                         Real fixedRate,
-                         Spread spread,
-                         const Date& refPeriodStart,
-                         const Date& refPeriodEnd,
-                         const Date& exCouponDate)
-    : CPICoupon(Null<Real>(), baseDate, paymentDate, nominal, startDate, endDate, index,
-                observationLag, observationInterpolation, dayCounter,
-                fixedRate, spread, refPeriodStart, refPeriodEnd, exCouponDate) {}
-
-    CPICoupon::CPICoupon(Real baseCPI,
-                         const Date& baseDate,
-                         const Date& paymentDate,
-                         Real nominal,
-                         const Date& startDate,
-                         const Date& endDate,
-                         const ext::shared_ptr<ZeroInflationIndex>& index,
-                         const Period& observationLag,
-                         CPI::InterpolationType observationInterpolation,
-                         const DayCounter& dayCounter,
-                         Real fixedRate,
-                         Spread spread,
-                         const Date& refPeriodStart,
-                         const Date& refPeriodEnd,
-                         const Date& exCouponDate)
     : InflationCoupon(paymentDate, nominal, startDate, endDate, 0,
                       index, observationLag, dayCounter,
                       refPeriodStart, refPeriodEnd, exCouponDate),
-      baseCPI_(baseCPI), fixedRate_(fixedRate), spread_(spread),
+      baseCPI_(baseCPI), fixedRate_(fixedRate),
       observationInterpolation_(observationInterpolation), baseDate_(baseDate) {
 
         QL_REQUIRE(index_, "no index provided");
-        QL_REQUIRE(
-            baseCPI_ != Null<Rate>() || baseDate != Null<Date>(),
-            "baseCPI and baseDate can not be both null, provide a valid baseCPI or baseDate");
+        QL_REQUIRE(baseCPI_ != Null<Rate>() || baseDate != Date(),
+                   "baseCPI and baseDate can not be both null, provide a valid baseCPI or baseDate");
         QL_REQUIRE(baseCPI_ == Null<Rate>() || std::fabs(baseCPI_) > 1e-16,
                    "|baseCPI_| < 1e-16, future divide-by-zero problem");
     }
 
-    QL_DEPRECATED_ENABLE_WARNING
-
     void CPICoupon::accept(AcyclicVisitor& v) {
         auto* v1 = dynamic_cast<Visitor<CPICoupon>*>(&v);
         if (v1 != nullptr)
@@ -210,7 +150,7 @@ namespace QuantLib {
       interpolation_(interpolation), frequency_(index ? index->frequency() : NoFrequency) {
         QL_REQUIRE(index, "no index provided");
         QL_REQUIRE(
-            baseFixing_ != Null<Rate>() || baseDate != Null<Date>(),
+            baseFixing_ != Null<Rate>() || baseDate != Date(),
             "baseCPI and baseDate can not be both null, provide a valid baseCPI or baseDate");
         QL_REQUIRE(baseFixing_ == Null<Rate>() || std::fabs(baseFixing_) > 1e-16,
                    "|baseCPI_| < 1e-16, future divide-by-zero problem");
@@ -226,44 +166,23 @@ namespace QuantLib {
     }
 
     Real CPICashFlow::baseFixing() const {
-        return baseFixing_;
+        if (baseFixing_ != Null<Rate>())
+            return baseFixing_;
+        else
+            return CPI::laggedFixing(cpiIndex(), baseDate(), 0 * Months, interpolation_);
     }
 
     Real CPICashFlow::indexFixing() const {
-        if (observationDate_ != Date()) {
-            return CPI::laggedFixing(cpiIndex(), observationDate_, observationLag_, interpolation_);
-        } else {
-            // we get to this branch when the deprecated constructor was used; it will be phased out
-            return CPI::laggedFixing(cpiIndex(), fixingDate() + observationLag_, observationLag_,
-                                     interpolation_);
-        }
+        return CPI::laggedFixing(cpiIndex(), observationDate_, observationLag_, interpolation_);
     }
 
-    Real CPICashFlow::amount() const {
-        Rate I0 = baseFixing();
-
-        // If BaseFixing is null, use the observed index fixing
-        if (I0 == Null<Rate>()) {
-            I0 = IndexedCashFlow::baseFixing();
-        }
-
-        Rate I1 = indexFixing();
-
-        if (growthOnly())
-            return notional() * (I1 / I0 - 1.0);
-        else
-            return notional() * (I1 / I0);
-    }
-
-    CPILeg::CPILeg(const Schedule& schedule,
+    CPILeg::CPILeg(Schedule schedule,
                    ext::shared_ptr<ZeroInflationIndex> index,
                    const Real baseCPI,
                    const Period& observationLag)
-    : schedule_(schedule), index_(std::move(index)), baseCPI_(baseCPI),
+    : schedule_(std::move(schedule)), index_(std::move(index)), baseCPI_(baseCPI),
       observationLag_(observationLag), paymentDayCounter_(Thirty360(Thirty360::BondBasis)),
-      paymentCalendar_(schedule.calendar()),
-
-      spreads_(std::vector<Real>(1, 0)), baseDate_(Null<Date>()) {}
+      paymentCalendar_(schedule_.calendar()) {}
 
 
     CPILeg& CPILeg::withObservationInterpolation(CPI::InterpolationType interp) {
@@ -312,16 +231,6 @@ namespace QuantLib {
         return *this;
     }
 
-    CPILeg& CPILeg::withSpreads(Spread spread) {
-        spreads_ = std::vector<Spread>(1,spread);
-        return *this;
-    }
-
-    CPILeg& CPILeg::withSpreads(const std::vector<Spread>& spreads) {
-        spreads_ = spreads;
-        return *this;
-    }
-
     CPILeg& CPILeg::withCaps(Rate cap) {
         caps_ = std::vector<Rate>(1,cap);
         return *this;
@@ -366,16 +275,15 @@ namespace QuantLib {
         Size n = schedule_.size()-1;
         Leg leg;
         leg.reserve(n+1);   // +1 for notional, we always have some sort ...
-        
+
         Date baseDate = baseDate_;
         // BaseDate and baseCPI are not given, use the first date as startDate and the baseFixingg
         // should be at startDate - observationLag
-        
+
         if (n>0) {
-            QL_REQUIRE(!fixedRates_.empty() || !spreads_.empty(),
-                       "no fixedRates or spreads given");
-            
-            if (baseDate_ == Null<Date>() && baseCPI_ == Null<Real>()) {
+            QL_REQUIRE(!fixedRates_.empty(), "no fixedRates given");
+
+            if (baseDate_ == Date() && baseCPI_ == Null<Real>()) {
                 baseDate = schedule_.date(0) - observationLag_;
             }
 
@@ -404,13 +312,13 @@ namespace QuantLib {
                     refEnd = schedule_.calendar().adjust(start + schedule_.tenor(), bdc);
                 }
                 if (detail::get(fixedRates_, i, 1.0) == 0.0) { // fixed coupon
+                    // this looks like an optimization but I'm not sure it's worth it?
                     leg.push_back(ext::make_shared<FixedRateCoupon>
                                    (paymentDate, detail::get(notionals_, i, 0.0),
-                                    detail::effectiveFixedRate(spreads_,caps_,floors_,i),
+                                    detail::effectiveFixedRate({},caps_,floors_,i),
                                     paymentDayCounter_, start, end, refStart, refEnd, exCouponDate));
                 } else { // zero inflation coupon
                     if (detail::noOption(caps_, floors_, i)) { // just swaplet
-                        QL_DEPRECATED_DISABLE_WARNING
                         leg.push_back(ext::make_shared<CPICoupon>
                                     (baseCPI_,    // all have same base for ratio
                                      baseDate,
@@ -421,9 +329,7 @@ namespace QuantLib {
                                      observationInterpolation_,
                                      paymentDayCounter_,
                                      detail::get(fixedRates_, i, 0.0),
-                                     detail::get(spreads_, i, 0.0),
                                      refStart, refEnd, exCouponDate));
-                        QL_DEPRECATED_ENABLE_WARNING
                     } else  {     // cap/floorlet
                         QL_FAIL("caps/floors on CPI coupons not implemented.");
                     }
@@ -435,7 +341,7 @@ namespace QuantLib {
         Date paymentDate = paymentCalendar_.adjust(schedule_.date(n), paymentAdjustment_);
         leg.push_back(ext::make_shared<CPICashFlow>
                           (detail::get(notionals_, n, 0.0), index_,
-                           baseDate, baseCPI_, 
+                           baseDate, baseCPI_,
                            schedule_.date(n), observationLag_, observationInterpolation_,
                            paymentDate, subtractInflationNominal_));
 
@@ -446,4 +352,3 @@ namespace QuantLib {
     }
 
 }
-
