@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -53,7 +53,10 @@ namespace QuantLib {
     class InflationCouponPricer: public virtual Observer,
                                  public virtual Observable {
     public:
+      QL_DEPRECATED_DISABLE_WARNING
+      InflationCouponPricer() = default;
       ~InflationCouponPricer() override = default;
+      QL_DEPRECATED_ENABLE_WARNING
       //! \name Interface
       //@{
       virtual Real swapletPrice() const = 0;
@@ -70,8 +73,7 @@ namespace QuantLib {
       void update() override { notifyObservers(); }
       //@}
     protected:
-        Handle<YieldTermStructure> rateCurve_;
-        Date paymentDate_;
+      Date paymentDate_;
     };
 
 
