@@ -10,7 +10,7 @@ QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
-<http://quantlib.org/license.shtml>.
+<https://www.quantlib.org/license.shtml>.
 
 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -29,6 +29,7 @@ FOR A PARTICULAR PURPOSE.  See the license for more details.
 #include <ql/termstructures/volatility/optionlet/optionletvolatilitystructure.hpp>
 #include <ql/termstructures/volatility/smilesection.hpp>
 #include <ql/time/dategenerationrule.hpp>
+#include <utility>
 
 
 namespace QuantLib {
@@ -48,20 +49,20 @@ namespace QuantLib {
             Real fraRateTarg_;
             std::vector<Real> v_;
             // implement transformation formula
-            virtual Volatility volatilityImpl(Rate strike) const;
+            Volatility volatilityImpl(Rate strike) const override;
 
           public:
             // constructor includes actual transformation details
             TenorOptionletSmileSection(const TenorOptionletVTS& volTS, Time optionTime);
 
             // further SmileSection interface methods
-            virtual Real minStrike() const {
+            Real minStrike() const override {
                 return baseSmileSection_[0]->minStrike() + fraRateTarg_ - fraRateBase_[0];
             }
-            virtual Real maxStrike() const {
+            Real maxStrike() const override {
                 return baseSmileSection_[0]->maxStrike() + fraRateTarg_ - fraRateBase_[0];
             }
-            virtual Real atmLevel() const { return fraRateTarg_; }
+            Real atmLevel() const override { return fraRateTarg_; }
         };
 
         Handle<OptionletVolatilityStructure> baseVTS_;
@@ -75,7 +76,8 @@ namespace QuantLib {
           public:
             // return the correlation between two FRA rates starting at start1 and start2
             virtual Real operator()(const Time& start1, const Time& start2) const = 0;
-            virtual ~CorrelationStructure(){};
+            virtual ~CorrelationStructure() = default;
+            ;
         };
 
         // very basic choice for correlation structure
@@ -85,10 +87,10 @@ namespace QuantLib {
             ext::shared_ptr<Interpolation> beta_;
 
           public:
-            TwoParameterCorrelation(const ext::shared_ptr<Interpolation>& rhoInf,
-                                    const ext::shared_ptr<Interpolation>& beta)
-            : rhoInf_(rhoInf), beta_(beta) {}
-            Real operator()(const Time& start1, const Time& start2) const {
+            TwoParameterCorrelation(ext::shared_ptr<Interpolation> rhoInf,
+                                    ext::shared_ptr<Interpolation> beta)
+            : rhoInf_(std::move(rhoInf)), beta_(std::move(beta)) {}
+            Real operator()(const Time& start1, const Time& start2) const override {
                 Real rhoInf = (*rhoInf_)(start1);
                 Real beta = (*beta_)(start1);
                 Real rho = rhoInf + (1.0 - rhoInf) * exp(-beta * fabs(start2 - start1));
@@ -98,34 +100,34 @@ namespace QuantLib {
 
         // constructor
         TenorOptionletVTS(const Handle<OptionletVolatilityStructure>& baseVTS,
-                          const ext::shared_ptr<IborIndex>& baseIndex,
-                          const ext::shared_ptr<IborIndex>& targIndex,
-                          const ext::shared_ptr<CorrelationStructure>& correlation);
+                          ext::shared_ptr<IborIndex> baseIndex,
+                          ext::shared_ptr<IborIndex> targIndex,
+                          ext::shared_ptr<CorrelationStructure> correlation);
 
         // Termstructure interface
 
         //! the latest date for which the curve can return values
-        virtual Date maxDate() const { return baseVTS_->maxDate(); }
+        Date maxDate() const override { return baseVTS_->maxDate(); }
 
         // VolatilityTermstructure interface
 
         //! implements the actual smile calculation in derived classes
-        virtual ext::shared_ptr<SmileSection> smileSectionImpl(Time optionTime) const {
+        ext::shared_ptr<SmileSection> smileSectionImpl(Time optionTime) const override {
             return ext::shared_ptr<SmileSection>(new TenorOptionletSmileSection(*this, optionTime));
         }
         //! implements the actual volatility calculation in derived classes
-        virtual Volatility volatilityImpl(Time optionTime, Rate strike) const {
+        Volatility volatilityImpl(Time optionTime, Rate strike) const override {
             return smileSection(optionTime)->volatility(strike);
         }
 
 
         //! the minimum strike for which the term structure can return vols
-        virtual Rate minStrike() const { return baseVTS_->minStrike(); }
+        Rate minStrike() const override { return baseVTS_->minStrike(); }
         //! the maximum strike for which the term structure can return vols
-        virtual Rate maxStrike() const { return baseVTS_->maxStrike(); }
+        Rate maxStrike() const override { return baseVTS_->maxStrike(); }
 
         // the methodology is designed for normal volatilities
-        VolatilityType volatilityType() const { return Normal; }
+        VolatilityType volatilityType() const override { return Normal; }
     };
 
     typedef TenorOptionletVTS::CorrelationStructure TenorOptionletVTSCorrelationStructure;
