@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -35,14 +35,15 @@ namespace QuantLib {
         : public ContinuousAveragingAsianOption::engine {
       public:
         ContinuousArithmeticAsianVecerEngine(
-            const ext::shared_ptr<GeneralizedBlackScholesProcess>& process,
-            const Handle<Quote>& currentAverage,
+            ext::shared_ptr<GeneralizedBlackScholesProcess> process,
+            Handle<Quote> currentAverage,
             Date startDate,
             Size timeSteps = 100,
             Size assetSteps = 100,
             Real z_min = -1.0,
             Real z_max = 1.0);
-        void calculate() const;
+        void calculate() const override;
+
       protected:
         // Replication of average by holding this amount in assets
         Real cont_strategy(Time t, Time T1,Time T2,Real v, Real r) const; 
