@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -49,15 +49,15 @@ namespace QuantLib {
         HimalayaOption(const std::vector<Date>& fixingDates,
                        Real strike);
 
-        void setupArguments(PricingEngine::arguments*) const;
+        void setupArguments(PricingEngine::arguments*) const override;
+
       private:
         std::vector<Date> fixingDates_;
     };
 
     class HimalayaOption::arguments : public MultiAssetOption::arguments {
       public:
-        arguments();
-        void validate() const;
+        void validate() const override;
         std::vector<Date> fixingDates;
     };
 
