@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -59,7 +59,7 @@ namespace QuantLib {
                                                         maxSamples_);
             results_.value = this->mcModel_->sampleAccumulator().mean();
 
-            if (RNG::allowsErrorEstimate) {
+            if constexpr (RNG::allowsErrorEstimate) {
                 results_.errorEstimate =
                     this->mcModel_->sampleAccumulator().errorEstimate();
             }
