@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -36,13 +36,12 @@ namespace QuantLib {
         : public GenericEngine<VanillaVPPOption::arguments,
                                VanillaVPPOption::results> {
       public:
-        DynProgVPPIntrinsicValueEngine(
-            const std::vector<Real>& fuelPrices,
-            const std::vector<Real>& powerPrices,
-            Real fuelCostAddon,
-            const ext::shared_ptr<YieldTermStructure>& rTS);
+        DynProgVPPIntrinsicValueEngine(std::vector<Real> fuelPrices,
+                                       std::vector<Real> powerPrices,
+                                       Real fuelCostAddon,
+                                       ext::shared_ptr<YieldTermStructure> rTS);
 
-        void calculate() const;
+        void calculate() const override;
 
       private:
         const std::vector<Real> fuelPrices_;
