@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -53,9 +53,8 @@ namespace QuantLib {
       public:
         typedef Sample<Real> sample_type;
         explicit ZigguratRng(unsigned long seed = 0);
-        sample_type next() const {
-            return sample_type(nextGaussian(),1.0);
-        }
+        sample_type next() const { return {nextGaussian(), 1.0}; }
+
       private:
         mutable MersenneTwisterUniformRng mt32_;
         Real nextGaussian() const;
