@@ -14,13 +14,14 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the license for more details.
 */
 
+#include <ql/any.hpp>
 #include <ql/exercise.hpp>
 #include <ql/experimental/swaptions/irregularswaption.hpp>
 #include <ql/math/solvers1d/newtonsafe.hpp>
@@ -79,7 +80,7 @@ namespace QuantLib {
             auto vega_ = results_->additionalResults.find("vega");
             QL_REQUIRE(vega_ != results_->additionalResults.end(),
                        "vega not provided");
-            return boost::any_cast<Real>(vega_->second);
+            return ext::any_cast<Real>(vega_->second);
         }
     }
 
