@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -40,55 +40,59 @@ namespace QuantLib {
         //@{
         //! all market data are quotes
         NoArbSabrInterpolatedSmileSection(
-                           const Date& optionDate,
-                           const Handle<Quote>& forward,
-                           const std::vector<Rate>& strikes,
-                           bool hasFloatingStrikes,
-                           const Handle<Quote>& atmVolatility,
-                           const std::vector<Handle<Quote> >& volHandles,
-                           Real alpha, Real beta, Real nu, Real rho,
-                           bool isAlphaFixed = false, bool isBetaFixed = false,
-                           bool isNuFixed = false, bool isRhoFixed = false,
-                           bool vegaWeighted = true,
-                           const ext::shared_ptr<EndCriteria>& endCriteria
-                            = ext::shared_ptr<EndCriteria>(),
-                           const ext::shared_ptr<OptimizationMethod>& method
-                            = ext::shared_ptr<OptimizationMethod>(),
-                           const DayCounter& dc = Actual365Fixed()
-                           );
+            const Date& optionDate,
+            Handle<Quote> forward,
+            const std::vector<Rate>& strikes,
+            bool hasFloatingStrikes,
+            Handle<Quote> atmVolatility,
+            const std::vector<Handle<Quote> >& volHandles,
+            Real alpha,
+            Real beta,
+            Real nu,
+            Real rho,
+            bool isAlphaFixed = false,
+            bool isBetaFixed = false,
+            bool isNuFixed = false,
+            bool isRhoFixed = false,
+            bool vegaWeighted = true,
+            ext::shared_ptr<EndCriteria> endCriteria = ext::shared_ptr<EndCriteria>(),
+            ext::shared_ptr<OptimizationMethod> method = ext::shared_ptr<OptimizationMethod>(),
+            const DayCounter& dc = Actual365Fixed());
         //! no quotes
         NoArbSabrInterpolatedSmileSection(
-                           const Date& optionDate,
-                           const Rate& forward,
-                           const std::vector<Rate>& strikes,
-                           bool hasFloatingStrikes,
-                           const Volatility& atmVolatility,
-                           const std::vector<Volatility>& vols,
-                           Real alpha, Real beta, Real nu, Real rho,
-                           bool isAlphaFixed = false, bool isBetaFixed = false,
-                           bool isNuFixed = false, bool isRhoFixed = false,
-                           bool vegaWeighted = true,
-                           const ext::shared_ptr<EndCriteria>& endCriteria
-                            = ext::shared_ptr<EndCriteria>(),
-                           const ext::shared_ptr<OptimizationMethod>& method
-                            = ext::shared_ptr<OptimizationMethod>(),
-                           const DayCounter& dc = Actual365Fixed()
-                           );
+            const Date& optionDate,
+            const Rate& forward,
+            const std::vector<Rate>& strikes,
+            bool hasFloatingStrikes,
+            const Volatility& atmVolatility,
+            const std::vector<Volatility>& vols,
+            Real alpha,
+            Real beta,
+            Real nu,
+            Real rho,
+            bool isAlphaFixed = false,
+            bool isBetaFixed = false,
+            bool isNuFixed = false,
+            bool isRhoFixed = false,
+            bool vegaWeighted = true,
+            ext::shared_ptr<EndCriteria> endCriteria = ext::shared_ptr<EndCriteria>(),
+            ext::shared_ptr<OptimizationMethod> method = ext::shared_ptr<OptimizationMethod>(),
+            const DayCounter& dc = Actual365Fixed());
         //@}
         //! \name LazyObject interface
         //@{
-        virtual void performCalculations() const;
-        virtual void update();
+        void performCalculations() const override;
+        void update() override;
         //@}
         //! \name SmileSection interface
         //@{
-        Real minStrike () const;
-        Real maxStrike () const;
-        Real atmLevel() const;
+        Real minStrike() const override;
+        Real maxStrike() const override;
+        Real atmLevel() const override;
         //@}
-        Real varianceImpl(Rate strike) const;
-        Volatility volatilityImpl(Rate strike) const;
-         //! \name Inspectors
+        Real varianceImpl(Rate strike) const override;
+        Volatility volatilityImpl(Rate strike) const override;
+        //! \name Inspectors
         //@{
         Real alpha() const;
         Real beta() const;
