@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -36,26 +36,30 @@ class NoArbSabrSmileSection : public SmileSection {
   public:
     NoArbSabrSmileSection(Time timeToExpiry,
                           Rate forward,
-                          const std::vector<Real>& sabrParameters,
-                          Real shift = 0.0);
+                          std::vector<Real> sabrParameters,
+                          Real shift = 0.0,
+                          VolatilityType volatilityType = VolatilityType::ShiftedLognormal);
     NoArbSabrSmileSection(const Date& d,
                           Rate forward,
-                          const std::vector<Real>& sabrParameters,
+                          std::vector<Real> sabrParameters,
                           const DayCounter& dc = Actual365Fixed(),
-                          Real shift = 0.0);
-    Real minStrike() const { return 0.0; }
-    Real maxStrike() const { return QL_MAX_REAL; }
-    Real atmLevel() const { return forward_; }
-    Real optionPrice(Rate strike, Option::Type type = Option::Call,
-                     Real discount = 1.0) const;
-    Real digitalOptionPrice(Rate strike, Option::Type type = Option::Call,
-                            Real discount = 1.0, Real gap = 1.0e-5) const;
-    Real density(Rate strike, Real discount = 1.0, Real gap = 1.0E-4) const;
+                          Real shift = 0.0,
+                          VolatilityType volatilityType = VolatilityType::ShiftedLognormal);
+    Real minStrike() const override { return 0.0; }
+    Real maxStrike() const override { return QL_MAX_REAL; }
+    Real atmLevel() const override { return forward_; }
+    Real
+    optionPrice(Rate strike, Option::Type type = Option::Call, Real discount = 1.0) const override;
+    Real digitalOptionPrice(Rate strike,
+                            Option::Type type = Option::Call,
+                            Real discount = 1.0,
+                            Real gap = 1.0e-5) const override;
+    Real density(Rate strike, Real discount = 1.0, Real gap = 1.0E-4) const override;
 
     ext::shared_ptr<NoArbSabrModel> model() { return model_; }
 
   protected:
-    Volatility volatilityImpl(Rate strike) const;
+    Volatility volatilityImpl(Rate strike) const override;
 
   private:
     void init();
