@@ -11,7 +11,7 @@ QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
-<http://quantlib.org/license.shtml>.
+<https://www.quantlib.org/license.shtml>.
 
 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -40,8 +40,7 @@ namespace QuantLib {
     class Jibar : public IborIndex {
       public:
         Jibar(const Period& tenor,
-              const Handle<YieldTermStructure>& h =
-                                    Handle<YieldTermStructure>())
+              const Handle<YieldTermStructure>& h = {})
         : IborIndex("Jibar", tenor, 0, ZARCurrency(),
                 SouthAfrica(), ModifiedFollowing, false,
                 Actual365Fixed(), h) {}
