@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -31,8 +31,7 @@ namespace QuantLib {
     //! %Sofr (Secured Overnight Financing Rate) index.
     class Sofr : public OvernightIndex {
       public:
-        explicit Sofr(const Handle<YieldTermStructure>& h =
-                                    Handle<YieldTermStructure>());
+        explicit Sofr(const Handle<YieldTermStructure>& h = {});
     };
 
 }
