@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -27,11 +27,20 @@ namespace QuantLib {
         : Option(ext::shared_ptr<Payoff>(),
                  const_cast<Swaption &>(fromSwaption).exercise()),
           swap_(ext::make_shared<NonstandardSwap>(
-              *fromSwaption.underlyingSwap())),
+              *fromSwaption.underlying())),
           settlementType_(fromSwaption.settlementType()),
           settlementMethod_(fromSwaption.settlementMethod()) {
 
         registerWith(swap_);
+        // When we ask for the NPV of an expired swaption, the
+        // swap is not recalculated and thus wouldn't forward
+        // later notifications according to the default behavior of
+        // LazyObject instances.  This means that even if the
+        // evaluation date changes so that the swaption is no longer
+        // expired, the instrument wouldn't be notified and thus it
+        // wouldn't recalculate.  To avoid this, we override the
+        // default behavior of the underlying swap.
+        swap_->alwaysForwardNotifications();
     }
 
     NonstandardSwaption::NonstandardSwaption(ext::shared_ptr<NonstandardSwap> swap,
@@ -41,7 +50,7 @@ namespace QuantLib {
     : Option(ext::shared_ptr<Payoff>(), exercise), swap_(std::move(swap)),
       settlementType_(delivery), settlementMethod_(settlementMethod) {
         registerWith(swap_);
-        registerWithObservables(swap_);
+        swap_->alwaysForwardNotifications();
     }
 
     bool NonstandardSwaption::isExpired() const {
