@@ -15,7 +15,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -113,14 +113,6 @@ namespace QuantLib {
         const ext::shared_ptr<FixedVsFloatingSwap>& underlying() const {
             return swap_;
         }
-        /*! \deprecated Use the Swaption::underlying method instead.
-                        Deprecated in version 1.34.
-        */
-        [[deprecated("Use the Swaption::underlying method instead")]]
-        const ext::shared_ptr<VanillaSwap>& underlyingSwap() const {
-            QL_REQUIRE(vanilla_, "underlying is not a vanilla swap");
-            return vanilla_;
-        }
         //@}
         //! implied volatility
         Volatility impliedVolatility(
