@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -32,10 +32,6 @@ namespace QuantLib {
     //! Farlie-Gumbel-Morgenstern copula
     class FarlieGumbelMorgensternCopula {
       public:
-        typedef Real first_argument_type;
-        typedef Real second_argument_type;
-        typedef Real result_type;
-
         FarlieGumbelMorgensternCopula(Real theta);
         Real operator()(Real x, Real y) const;
       private:
