@@ -11,7 +11,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -56,7 +56,7 @@ namespace QuantLib {
         : Integrator(accuracy, maxIterations){}
 
       protected:
-        Real integrate(const ext::function<Real(Real)>& f, Real a, Real b) const override {
+        Real integrate(const std::function<Real(Real)>& f, Real a, Real b) const override {
 
             // start from the coarsest trapezoid...
             Size N = 1;
@@ -82,7 +82,7 @@ namespace QuantLib {
 
     // Integration policies
     struct Default {
-        inline static Real integrate(const ext::function<Real (Real)>& f, 
+        static Real integrate(const std::function<Real (Real)>& f, 
                                      Real a, 
                                      Real b, 
                                      Real I, 
@@ -95,11 +95,11 @@ namespace QuantLib {
                 sum += f(x);
             return (I + dx*sum)/2.0;
         }
-        inline static Size nbEvalutions(){ return 2;}
+        static Size nbEvalutions(){ return 2;}
     };
 
     struct MidPoint {
-        inline static Real integrate(const ext::function<Real (Real)>& f,
+        static Real integrate(const std::function<Real (Real)>& f,
                                      Real a, 
                                      Real b, 
                                      Real I, 
@@ -113,7 +113,7 @@ namespace QuantLib {
                 sum += f(x) + f(x+D);
             return (I + dx*sum)/3.0;
         }
-        inline static Size nbEvalutions(){ return 3;}
+        static Size nbEvalutions(){ return 3;}
     };
 
 }
