@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -466,6 +466,7 @@ namespace QuantLib {
     template <Size i> class MultiCubicSpline {
         typedef typename detail::Int2Type<i>::c_spline c_spline;
         typedef typename detail::Int2Type<i>::c_splint c_splint;
+        
       public:
         typedef typename c_splint::argument_type argument_type;
         typedef typename c_splint::result_type result_type;
@@ -474,14 +475,17 @@ namespace QuantLib {
         typedef typename c_splint::output_data output_data;
         typedef typename c_splint::dimensions dimensions;
         typedef typename c_splint::data data;
+        
         MultiCubicSpline(const SplineGrid& grid, const data_table &y,
-                         const std::vector<bool>& ae =
-                                             std::vector<bool>(20, false))
-        : grid_(grid), y_(y), ae_(ae), v_(grid), v1_(grid),
+                         std::vector<bool> ae = {})
+        : grid_(grid), y_(y), ae_(std::move(ae)), v_(grid), v1_(grid),
           v2_(grid), y2_(grid) {
+            if (ae_.empty())
+                ae_ = std::vector<bool>(grid.size(), false);
             set_shared_increments();
             c_spline(d_, d2_, y_, y2_, v_);
         }
+        
         result_type operator()(const argument_type& x) const {
             set_shared_coefficients(x);
             c_splint(a_, b_, a2_, b2_, i_, d_, d2_, y_, y2_,
@@ -490,10 +494,11 @@ namespace QuantLib {
         }
         void set_shared_increments() const;
         void set_shared_coefficients(const argument_type &x) const;
+        
       private:
         const SplineGrid &grid_;
         const data_table &y_;
-        const std::vector<bool> &ae_;
+        std::vector<bool> ae_;
         mutable return_type a_, b_, a2_, b2_;
         mutable output_data v_, v1_, v2_;
         mutable result_type res_;
@@ -544,8 +549,7 @@ namespace QuantLib {
             const std::vector<Real> &v = grid_[j];
             if(x[j] < v[0] || x[j] >= v[sz]) {
                 QL_REQUIRE(ae_[j],
-                           "Dimension " << j
-                           << ": extrapolation is not allowed.");
+                           "Dimension " << j << ": extrapolation is not allowed.");
                 a_[j] = 1.0, a2_[j] = b_[j] = b2_[j] = 0.0;
                 k =  x[j] < v[0] ? 0 : sz;
             }
@@ -565,4 +569,3 @@ namespace QuantLib {
 
 
 #endif
-
