@@ -65,8 +65,7 @@ or guarantee.
 #include <cmath>
 #include <cstdio>
 
-namespace QuantLib {
-  namespace MINPACK {
+namespace QuantLib::MINPACK {
 #define BUG 0
 /* resolution of arithmetic */
 double MACHEP = 1.2e-16;
@@ -1668,7 +1667,6 @@ if(nprint > 0)
 */
 }
 }
-}
 
 /************************fdjac2.c*************************/
 
