@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -47,7 +47,7 @@ namespace QuantLib {
         //! Get and store one after another.
         static BigNatural get(Size absoluteIndex);
       private:
-        PrimeNumbers() {}
+        PrimeNumbers() = default;
         static BigNatural nextPrimeNumber();
         static std::vector<BigNatural> primeNumbers_;
     };
