@@ -12,7 +12,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -20,13 +20,12 @@
  */
 
 #include <ql/methods/finitedifferences/schemes/expliciteulerscheme.hpp>
+#include <utility>
 
 namespace QuantLib {
-    ExplicitEulerScheme::ExplicitEulerScheme(
-        const ext::shared_ptr<FdmLinearOpComposite> & map,
-        const bc_set& bcSet) :
-        dt_(Null<Real>()), map_(map), bcSet_(bcSet) {
-    }
+    ExplicitEulerScheme::ExplicitEulerScheme(ext::shared_ptr<FdmLinearOpComposite> map,
+                                             const bc_set& bcSet)
+    : dt_(Null<Real>()), map_(std::move(map)), bcSet_(bcSet) {}
 
     void ExplicitEulerScheme::step(array_type& a, Time t) {
         step(a, t, 1.0);
