@@ -12,7 +12,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -34,7 +34,7 @@ namespace QuantLib {
     : dt_(Null<Real>()), iterations_(ext::make_shared<Size>(0U)), relTol_(relTol),
       map_(std::move(map)), bcSet_(bcSet), solverType_(solverType) {}
 
-    Disposable<Array> ImplicitEulerScheme::apply(const Array& r, Real theta) const {
+    Array ImplicitEulerScheme::apply(const Array& r, Real theta) const {
         return r - (theta*dt_)*map_->apply(r);
     }
 
