@@ -12,7 +12,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -62,8 +62,8 @@ namespace QuantLib {
       public:
         typedef FdmLinearOp::array_type array_type;
 
-        FdmBackwardSolver(const ext::shared_ptr<FdmLinearOpComposite>& map,
-                          const FdmBoundaryConditionSet& bcSet,
+        FdmBackwardSolver(ext::shared_ptr<FdmLinearOpComposite> map,
+                          FdmBoundaryConditionSet bcSet,
                           const ext::shared_ptr<FdmStepConditionComposite>& condition,
                           const FdmSchemeDesc& schemeDesc);
 
