@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -33,13 +33,12 @@ namespace QuantLib {
 
     class FdmSimpleStorageCondition : public StepCondition<Array> {
       public:
-          FdmSimpleStorageCondition(
-                  const std::vector<Time> & exerciseTimes,
-                  const ext::shared_ptr<FdmMesher>& mesher,
-                  const ext::shared_ptr<FdmInnerValueCalculator>& calculator,
-                  Real changeRate);
+        FdmSimpleStorageCondition(std::vector<Time> exerciseTimes,
+                                  ext::shared_ptr<FdmMesher> mesher,
+                                  ext::shared_ptr<FdmInnerValueCalculator> calculator,
+                                  Real changeRate);
 
-        void applyTo(Array& a, Time t) const;
+        void applyTo(Array& a, Time t) const override;
 
       private:
         const std::vector<Time> exerciseTimes_;
