@@ -12,7 +12,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -41,9 +41,9 @@ namespace QuantLib {
                            const Date& referenceDate,
                            const DayCounter& dayCounter,
                            Size equityDirection);
-        
-        void applyTo(Array& a, Time t) const;
- 
+
+        void applyTo(Array& a, Time t) const override;
+
         const std::vector<Time>& dividendTimes() const;
         const std::vector<Date>& dividendDates() const;
         const std::vector<Real>& dividends() const;
