@@ -10,14 +10,13 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the license for more details.
 */
 
-#include <ql/auto_ptr.hpp>
 #include <ql/models/marketmodels/callability/bermudanswaptionexercisevalue.hpp>
 #include <ql/models/marketmodels/curvestate.hpp>
 #include <ql/models/marketmodels/utilities.hpp>
@@ -29,7 +28,7 @@ namespace QuantLib {
     BermudanSwaptionExerciseValue::BermudanSwaptionExerciseValue(
         const std::vector<Time>& rateTimes, std::vector<ext::shared_ptr<Payoff> > payoffs)
     : numberOfExercises_(rateTimes.empty() ? 0 : rateTimes.size() - 1), rateTimes_(rateTimes),
-      payoffs_(std::move(payoffs)), currentIndex_(0) {
+      payoffs_(std::move(payoffs)) {
 
         checkIncreasingTimes(rateTimes);
         QL_REQUIRE(numberOfExercises_>0,
@@ -79,10 +78,9 @@ namespace QuantLib {
          return cf_;
     }
 
-    QL_UNIQUE_OR_AUTO_PTR<MarketModelExerciseValue>
+    std::unique_ptr<MarketModelExerciseValue>
     BermudanSwaptionExerciseValue::clone() const {
-        return QL_UNIQUE_OR_AUTO_PTR<MarketModelExerciseValue>(
-                                    new BermudanSwaptionExerciseValue(*this));
+        return std::unique_ptr<MarketModelExerciseValue>(new BermudanSwaptionExerciseValue(*this));
     }
 
 }
