@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -43,11 +43,7 @@ namespace QuantLib {
         void reset() override;
         bool exercise(const CurveState& currentState) const override;
         void nextStep(const CurveState& currentState) override;
-#if defined(QL_USE_STD_UNIQUE_PTR)
         std::unique_ptr<ExerciseStrategy<CurveState> > clone() const override;
-#else
-        std::auto_ptr<ExerciseStrategy<CurveState> > clone() const;
-        #endif
       private:
         Clone<MarketModelBasisSystem> basisSystem_;
         std::vector<std::vector<Real> > basisCoefficients_;
