@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -123,12 +123,8 @@ namespace QuantLib {
             explicit Impl(std::vector<Time> times) : times_(std::move(times)) {}
 
             Real value(const Array& params, Time t) const override {
-                Size size = times_.size();
-                for (Size i=0; i<size; i++) {
-                    if (t<times_[i])
-                        return params[i];
-                }
-                return params[size];
+                Size i = std::upper_bound(times_.begin(), times_.end(), t) - times_.begin();
+                return params[i];
             }
 
           private:
