@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -38,8 +38,8 @@ namespace QuantLib {
       public:
         ConstantEstimator(Size size)
         : size_(size) {}
-        TimeSeries<Volatility> calculate(const TimeSeries<Volatility>&);
-        void calibrate(const TimeSeries<Volatility>&) {}
+        TimeSeries<Volatility> calculate(const TimeSeries<Volatility>&) override;
+        void calibrate(const TimeSeries<Volatility>&) override {}
     };
 
 }
