@@ -11,7 +11,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/reference/license.html>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -26,6 +26,8 @@
 #define quantlib_money_hpp
 
 #include <ql/currency.hpp>
+#include <ql/patterns/singleton.hpp>
+#include <utility>
 
 namespace QuantLib {
 
@@ -37,9 +39,9 @@ namespace QuantLib {
       public:
         //! \name Constructors
         //@{
-        Money();
-        Money(const Currency& currency, Decimal value);
-        Money(Decimal value, const Currency& currency);
+        Money() = default;
+        Money(Currency currency, Decimal value);
+        Money(Decimal value, Currency currency);
         //@}
         //! \name Inspectors
         //@{
@@ -75,14 +77,44 @@ namespace QuantLib {
                                          currency of the first
                                          operand */
         };
-        static ConversionType conversionType;
-        static Currency baseCurrency;
+        // Money::Settings forward declaration
+        class Settings;
         //@}
       private:
-        Decimal value_;
+        Decimal value_ = 0.0;
         Currency currency_;
+
+        // temporary support for old syntax
+        struct BaseCurrencyProxy {
+          public:
+            BaseCurrencyProxy& operator=(const Currency&);
+            operator Currency() const;
+        };
+
+        struct ConversionTypeProxy {
+          public:
+            ConversionTypeProxy& operator=(Money::ConversionType);
+            operator Money::ConversionType() const;
+        };
     };
 
+    //! Per-session settings for the Money class
+    class Money::Settings : public Singleton<Money::Settings> {
+        friend class Singleton<Money::Settings>;
+      private:
+        Settings() = default;
+
+      public:
+        const Money::ConversionType & conversionType() const;
+        Money::ConversionType & conversionType();
+
+        const Currency & baseCurrency() const;
+        Currency & baseCurrency();
+
+      private:
+        Money::ConversionType conversionType_ = Money::NoConversion;
+        Currency baseCurrency_;
+    };
 
     // More arithmetics and comparisons
 
@@ -132,14 +164,11 @@ namespace QuantLib {
 
     // inline definitions
 
-    inline Money::Money()
-    : value_(0.0) {}
+    inline Money::Money(Currency currency, Decimal value)
+    : value_(value), currency_(std::move(currency)) {}
 
-    inline Money::Money(const Currency& currency, Decimal value)
-    : value_(value), currency_(currency) {}
-
-    inline Money::Money(Decimal value, const Currency& currency)
-    : value_(value), currency_(currency) {}
+    inline Money::Money(Decimal value, Currency currency)
+    : value_(value), currency_(std::move(currency)) {}
 
     inline const Currency& Money::currency() const {
         return currency_;
