@@ -11,7 +11,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -90,7 +90,7 @@ namespace QuantLib {
         //@}
 
         // this is a smell, but we need it. We'll rethink it later.
-        virtual Disposable<Array> grid(Time) const = 0;
+        virtual Array grid(Time) const = 0;
       protected:
         TimeGrid t_;
     };
