@@ -11,7 +11,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -35,11 +35,13 @@ namespace QuantLib {
         DiscretizedCapFloor(const CapFloor::arguments& args,
                             const Date& referenceDate,
                             const DayCounter& dayCounter);
-        void reset(Size size);
-        std::vector<Time> mandatoryTimes() const;
+        void reset(Size size) override;
+        std::vector<Time> mandatoryTimes() const override;
+
       protected:
-        void preAdjustValuesImpl();
-        void postAdjustValuesImpl();
+        void preAdjustValuesImpl() override;
+        void postAdjustValuesImpl() override;
+
       private:
         CapFloor::arguments arguments_;
         std::vector<Time> startTimes_;
