@@ -11,7 +11,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -26,6 +26,7 @@
 #define quantlib_integral_cds_engine_hpp
 
 #include <ql/instruments/creditdefaultswap.hpp>
+#include <ql/optional.hpp>
 
 namespace QuantLib {
 
@@ -35,7 +36,7 @@ namespace QuantLib {
                           Handle<DefaultProbabilityTermStructure>,
                           Real recoveryRate,
                           Handle<YieldTermStructure> discountCurve,
-                          const boost::optional<bool>& includeSettlementDateFlows = boost::none);
+                          const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt);
         void calculate() const override;
 
       private:
@@ -43,7 +44,7 @@ namespace QuantLib {
         Handle<DefaultProbabilityTermStructure> probability_;
         Real recoveryRate_;
         Handle<YieldTermStructure> discountCurve_;
-        boost::optional<bool> includeSettlementDateFlows_;
+        ext::optional<bool> includeSettlementDateFlows_;
     };
 
 }
