@@ -11,7 +11,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -90,7 +90,7 @@ namespace QuantLib {
         // the right level is needed in order to interpolate
         // the vol
         Handle<Quote> spot = process_->stateVariable();
-        QL_REQUIRE(spot->value() >= 0.0, "negative or null underlting given");
+        QL_REQUIRE(spot->value() > 0.0, "negative or null underlying given");
         Handle<YieldTermStructure> dividendYield(
             ext::shared_ptr<YieldTermStructure>(
                new ImpliedTermStructure(process_->dividendYield(),
