@@ -13,7 +13,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -203,7 +203,7 @@ namespace QuantLib {
         this->results_.value = this->mcModel_->sampleAccumulator().mean();
         this->results_.additionalResults["exerciseProbability"] =
             this->pathPricer_->exerciseProbability();
-        if (RNG::allowsErrorEstimate) {
+        if constexpr (RNG::allowsErrorEstimate) {
             this->results_.errorEstimate =
                 this->mcModel_->sampleAccumulator().errorEstimate();
         }
