@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -25,17 +25,14 @@
 #define quantlib_fd_black_scholes_shout_engine_hpp
 
 #include <ql/pricingengine.hpp>
-#include <ql/instruments/dividendvanillaoption.hpp>
+#include <ql/instruments/vanillaoption.hpp>
 #include <ql/methods/finitedifferences/solvers/fdmbackwardsolver.hpp>
 
 namespace QuantLib {
 
     class GeneralizedBlackScholesProcess;
 
-    QL_DEPRECATED_DISABLE_WARNING
-
-    class FdBlackScholesShoutEngine : public DividendVanillaOption::engine {
-        QL_DEPRECATED_ENABLE_WARNING
+    class FdBlackScholesShoutEngine : public VanillaOption::engine {
       public:
         // Constructor
         explicit FdBlackScholesShoutEngine(
@@ -58,7 +55,6 @@ namespace QuantLib {
       private:
         const ext::shared_ptr<GeneralizedBlackScholesProcess> process_;
         DividendSchedule dividends_;
-        bool explicitDividends_;
         const Size tGrid_, xGrid_, dampingSteps_;
         const FdmSchemeDesc schemeDesc_;
     };
