@@ -12,7 +12,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -25,9 +25,9 @@
 namespace QuantLib {
 
     GeometricBrownianMotionProcess::GeometricBrownianMotionProcess(
-                                                          double initialValue,
-                                                          double mue,
-                                                          double sigma)
+                                                          Real initialValue,
+                                                          Real mue,
+                                                          Real sigma)
     : StochasticProcess1D(ext::shared_ptr<discretization>(
                                                     new EulerDiscretization)),
       initialValue_(initialValue), mue_(mue), sigma_(sigma) {}
