@@ -12,7 +12,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -32,8 +32,8 @@ namespace QuantLib {
     }
 
     Settings::Settings()
-    : includeReferenceDateEvents_(false),
-      enforcesTodaysHistoricFixings_(false) {}
+
+        = default;
 
     void Settings::anchorEvaluationDate() {
         // set to today's date if not already set.
@@ -48,11 +48,9 @@ namespace QuantLib {
 
     SavedSettings::SavedSettings()
     : evaluationDate_(Settings::instance().evaluationDate()),
-      includeReferenceDateEvents_(
-                        Settings::instance().includeReferenceDateEvents()),
+      includeReferenceDateEvents_(Settings::instance().includeReferenceDateEvents()),
       includeTodaysCashFlows_(Settings::instance().includeTodaysCashFlows()),
-      enforcesTodaysHistoricFixings_(
-                        Settings::instance().enforcesTodaysHistoricFixings()) {}
+      enforcesTodaysHistoricFixings_(Settings::instance().enforcesTodaysHistoricFixings()) {}
 
     SavedSettings::~SavedSettings() {
         try {
