@@ -11,7 +11,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -38,16 +38,15 @@ namespace QuantLib {
         Calendar calendar,
         BusinessDayConvention paymentConvention,
         const DayCounter& dayCounter,
-        ext::shared_ptr<ZeroInflationIndex> zii,
+        const ext::shared_ptr<ZeroInflationIndex>& zii,
         CPI::InterpolationType observationInterpolation)
-    : ZeroCouponInflationSwapHelper(quote, swapObsLag, maturity, std::move(calendar), paymentConvention,
-                                    dayCounter, std::move(zii), observationInterpolation, {}) {
+    : ZeroCouponInflationSwapHelper(
+        quote, swapObsLag, maturity, std::move(calendar), paymentConvention,
+        dayCounter, zii, observationInterpolation,
         // any nominal term structure will give the same result;
         // when calculating the fair rate, the equal discount factors
         // for the payments on the two legs will cancel out.
-        nominalTermStructure_ =
-            Handle<YieldTermStructure>(ext::make_shared<FlatForward>(0, NullCalendar(), 0.0, dayCounter));
-    }
+        Handle<YieldTermStructure>(ext::make_shared<FlatForward>(0, NullCalendar(), 0.0, dayCounter))) {}
 
     ZeroCouponInflationSwapHelper::ZeroCouponInflationSwapHelper(
         const Handle<Quote>& quote,
@@ -56,14 +55,18 @@ namespace QuantLib {
         Calendar calendar,
         BusinessDayConvention paymentConvention,
         DayCounter dayCounter,
-        ext::shared_ptr<ZeroInflationIndex> zii,
+        const ext::shared_ptr<ZeroInflationIndex>& zii,
         CPI::InterpolationType observationInterpolation,
         Handle<YieldTermStructure> nominalTermStructure)
-    : BootstrapHelper<ZeroInflationTermStructure>(quote), swapObsLag_(swapObsLag),
+    : RelativeDateBootstrapHelper<ZeroInflationTermStructure>(quote), swapObsLag_(swapObsLag),
       maturity_(maturity), calendar_(std::move(calendar)), paymentConvention_(paymentConvention),
-      dayCounter_(std::move(dayCounter)), zii_(std::move(zii)),
-      observationInterpolation_(observationInterpolation),
+      dayCounter_(std::move(dayCounter)), observationInterpolation_(observationInterpolation),
       nominalTermStructure_(std::move(nominalTermStructure)) {
+        zii_ = zii->clone(termStructureHandle_);
+        // We want to be notified of changes of fixings, but we don't
+        // want notifications from termStructureHandle_ (they would
+        // interfere with bootstrapping.)
+        zii_->unregisterWith(termStructureHandle_);
 
         auto fixingPeriod = inflationPeriod(maturity_ - swapObsLag_, zii_->frequency());
         auto interpolationPeriod = inflationPeriod(maturity, zii_->frequency());
@@ -89,8 +92,9 @@ namespace QuantLib {
                            << zii_->availabilityLag() << ": need (obsLag-index period) >= availLag");
         }
 
-        registerWith(Settings::instance().evaluationDate());
+        registerWith(zii_);
         registerWith(nominalTermStructure_);
+        ZeroCouponInflationSwapHelper::initializeDates();
     }
 
     QL_DEPRECATED_ENABLE_WARNING
@@ -101,33 +105,26 @@ namespace QuantLib {
         return zciis_->fairRate();
     }
 
-
-    void ZeroCouponInflationSwapHelper::setTermStructure(ZeroInflationTermStructure* z) {
-
-        BootstrapHelper<ZeroInflationTermStructure>::setTermStructure(z);
-
-        // set up a new ZCIIS
-        // but this one does NOT own its inflation term structure
-        const bool own = false;
-        Rate K = quote()->value();
-
-        // The effect of the new inflation term structure is
-        // felt via the effect on the inflation index
-        Handle<ZeroInflationTermStructure> zits(
-            ext::shared_ptr<ZeroInflationTermStructure>(z, null_deleter()), own);
-
-        ext::shared_ptr<ZeroInflationIndex> new_zii = zii_->clone(zits);
-
-        Real nominal = 1000000.0; // has to be something but doesn't matter what
-        Date start = nominalTermStructure_->referenceDate();
-        zciis_ = ext::make_shared<ZeroCouponInflationSwap>(Swap::Payer, nominal, start,
-                                                 maturity_, calendar_, paymentConvention_,
-                                                 dayCounter_, K, // fixed side & fixed rate
-                                                 new_zii, swapObsLag_, observationInterpolation_);
+    void ZeroCouponInflationSwapHelper::initializeDates() {
+        zciis_ = ext::make_shared<ZeroCouponInflationSwap>(
+            Swap::Payer, 1.0, evaluationDate_, maturity_, calendar_,
+            paymentConvention_, dayCounter_, 0.0, zii_, swapObsLag_,
+            observationInterpolation_);
         // Because very simple instrument only takes
         // standard discounting swap engine.
         zciis_->setPricingEngine(
-            ext::shared_ptr<PricingEngine>(new DiscountingSwapEngine(nominalTermStructure_)));
+            ext::make_shared<DiscountingSwapEngine>(nominalTermStructure_));
+    }
+
+    void ZeroCouponInflationSwapHelper::setTermStructure(ZeroInflationTermStructure* z) {
+        // do not set the relinkable handle as an observer -
+        // force recalculation when needed
+        bool observer = false;
+
+        ext::shared_ptr<ZeroInflationTermStructure> temp(z, null_deleter());
+        termStructureHandle_.linkTo(std::move(temp), observer);
+
+        RelativeDateBootstrapHelper<ZeroInflationTermStructure>::setTermStructure(z);
     }
 
 
@@ -138,13 +135,18 @@ namespace QuantLib {
         Calendar calendar,
         BusinessDayConvention paymentConvention,
         DayCounter dayCounter,
-        ext::shared_ptr<YoYInflationIndex> yii,
+        const ext::shared_ptr<YoYInflationIndex>& yii,
         CPI::InterpolationType interpolation,
         Handle<YieldTermStructure> nominalTermStructure)
-    : BootstrapHelper<YoYInflationTermStructure>(quote), swapObsLag_(swapObsLag),
+    : RelativeDateBootstrapHelper<YoYInflationTermStructure>(quote), swapObsLag_(swapObsLag),
       maturity_(maturity), calendar_(std::move(calendar)), paymentConvention_(paymentConvention),
-      dayCounter_(std::move(dayCounter)), yii_(std::move(yii)), interpolation_(interpolation),
+      dayCounter_(std::move(dayCounter)), interpolation_(interpolation),
       nominalTermStructure_(std::move(nominalTermStructure)) {
+        yii_ = yii->clone(termStructureHandle_);
+        // We want to be notified of changes of fixings, but we don't
+        // want notifications from termStructureHandle_ (they would
+        // interfere with bootstrapping.)
+        yii_->unregisterWith(termStructureHandle_);
 
         auto fixingPeriod = inflationPeriod(maturity_ - swapObsLag_, yii_->frequency());
         auto interpolationPeriod = inflationPeriod(maturity, yii_->frequency());
@@ -170,8 +172,9 @@ namespace QuantLib {
                        << yii_->availabilityLag() << ": need (obsLag-index period) >= availLag");
         }
 
-        registerWith(Settings::instance().evaluationDate());
+        registerWith(yii_);
         registerWith(nominalTermStructure_);
+        YearOnYearInflationSwapHelper::initializeDates();
     }
 
     YearOnYearInflationSwapHelper::YearOnYearInflationSwapHelper(
@@ -181,10 +184,10 @@ namespace QuantLib {
         Calendar calendar,
         BusinessDayConvention paymentConvention,
         DayCounter dayCounter,
-        ext::shared_ptr<YoYInflationIndex> yii,
+        const ext::shared_ptr<YoYInflationIndex>& yii,
         Handle<YieldTermStructure> nominalTermStructure)
     : YearOnYearInflationSwapHelper(quote, swapObsLag, maturity, std::move(calendar), paymentConvention,
-                                    std::move(dayCounter), std::move(yii), CPI::AsIndex, std::move(nominalTermStructure)) {}
+                                    std::move(dayCounter), yii, CPI::AsIndex, std::move(nominalTermStructure)) {}
 
 
     Real YearOnYearInflationSwapHelper::impliedQuote() const {
@@ -192,48 +195,39 @@ namespace QuantLib {
         return yyiis_->fairRate();
     }
 
-
-    void YearOnYearInflationSwapHelper::setTermStructure(YoYInflationTermStructure* y) {
-
-        BootstrapHelper<YoYInflationTermStructure>::setTermStructure(y);
-
-        // set up a new YYIIS
-        // but this one does NOT own its inflation term structure
-        const bool own = false;
-
-        // The effect of the new inflation term structure is
-        // felt via the effect on the inflation index
-        Handle<YoYInflationTermStructure> yyts(
-            ext::shared_ptr<YoYInflationTermStructure>(y, null_deleter()), own);
-
-        ext::shared_ptr<YoYInflationIndex> new_yii = yii_->clone(yyts);
-
+    void YearOnYearInflationSwapHelper::initializeDates() {
         // always works because tenor is always 1 year so
         // no problem with different days-in-month
-        Date from = Settings::instance().evaluationDate();
-        Date to = maturity_;
         Schedule fixedSchedule = MakeSchedule()
-                                     .from(from)
-                                     .to(to)
+                                     .from(evaluationDate_)
+                                     .to(maturity_)
                                      .withTenor(1 * Years)
                                      .withConvention(Unadjusted)
                                      .withCalendar(calendar_) // fixed leg gets cal from sched
                                      .backwards();
         const Schedule& yoySchedule = fixedSchedule;
-        Spread spread = 0.0;
-        Rate fixedRate = quote()->value();
 
-        Real nominal = 1000000.0; // has to be something but doesn't matter what
         yyiis_ = ext::make_shared<YearOnYearInflationSwap>(
-            Swap::Payer, nominal, fixedSchedule, fixedRate, dayCounter_,
-            yoySchedule, new_yii, swapObsLag_, interpolation_,
-            spread, dayCounter_, calendar_, paymentConvention_);
+            Swap::Payer, 1.0, fixedSchedule, 0.0, dayCounter_,
+            yoySchedule, yii_, swapObsLag_, interpolation_,
+            0.0, dayCounter_, calendar_, paymentConvention_);
 
         // The instrument takes a standard discounting swap engine.
         // The inflation-related work is done by the coupons.
 
         yyiis_->setPricingEngine(
-            ext::shared_ptr<PricingEngine>(new DiscountingSwapEngine(nominalTermStructure_)));
+            ext::make_shared<DiscountingSwapEngine>(nominalTermStructure_));
+    }
+
+    void YearOnYearInflationSwapHelper::setTermStructure(YoYInflationTermStructure* y) {
+        // do not set the relinkable handle as an observer -
+        // force recalculation when needed
+        bool observer = false;
+
+        ext::shared_ptr<YoYInflationTermStructure> temp(y, null_deleter());
+        termStructureHandle_.linkTo(std::move(temp), observer);
+
+        RelativeDateBootstrapHelper<YoYInflationTermStructure>::setTermStructure(y);
     }
 
 }
