@@ -11,7 +11,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -33,7 +33,8 @@
 namespace QuantLib {
 
     //! Zero-coupon inflation-swap bootstrap helper
-    class ZeroCouponInflationSwapHelper : public BootstrapHelper<ZeroInflationTermStructure> {
+    class ZeroCouponInflationSwapHelper
+        : public RelativeDateBootstrapHelper<ZeroInflationTermStructure> {
       public:
         ZeroCouponInflationSwapHelper(
             const Handle<Quote>& quote,
@@ -42,7 +43,7 @@ namespace QuantLib {
             Calendar calendar, // index may have null calendar as valid on every day
             BusinessDayConvention paymentConvention,
             const DayCounter& dayCounter,
-            ext::shared_ptr<ZeroInflationIndex> zii,
+            const ext::shared_ptr<ZeroInflationIndex>& zii,
             CPI::InterpolationType observationInterpolation);
 
         /*! \deprecated Use the overload that does not take a nominal curve.
@@ -56,14 +57,20 @@ namespace QuantLib {
             Calendar calendar,
             BusinessDayConvention paymentConvention,
             DayCounter dayCounter,
-            ext::shared_ptr<ZeroInflationIndex> zii,
+            const ext::shared_ptr<ZeroInflationIndex>& zii,
             CPI::InterpolationType observationInterpolation,
             Handle<YieldTermStructure> nominalTermStructure);
 
         void setTermStructure(ZeroInflationTermStructure*) override;
         Real impliedQuote() const override;
-
+        //! \name inspectors
+        //@{
+        // NOLINTNEXTLINE(cppcoreguidelines-noexcept-swap,performance-noexcept-swap)
+        ext::shared_ptr<ZeroCouponInflationSwap> swap() const { return zciis_; }
+        //@}
       protected:
+        void initializeDates() override;
+
         Period swapObsLag_;
         Date maturity_;
         Calendar calendar_;
@@ -73,19 +80,21 @@ namespace QuantLib {
         CPI::InterpolationType observationInterpolation_;
         ext::shared_ptr<ZeroCouponInflationSwap> zciis_;
         Handle<YieldTermStructure> nominalTermStructure_;
+        RelinkableHandle<ZeroInflationTermStructure> termStructureHandle_;
     };
 
 
     //! Year-on-year inflation-swap bootstrap helper
-    class YearOnYearInflationSwapHelper : public BootstrapHelper<YoYInflationTermStructure> {
+    class YearOnYearInflationSwapHelper
+        : public RelativeDateBootstrapHelper<YoYInflationTermStructure> {
       public:
         YearOnYearInflationSwapHelper(const Handle<Quote>& quote,
-                                      const Period& swapObsLag_,
+                                      const Period& swapObsLag,
                                       const Date& maturity,
                                       Calendar calendar,
                                       BusinessDayConvention paymentConvention,
                                       DayCounter dayCounter,
-                                      ext::shared_ptr<YoYInflationIndex> yii,
+                                      const ext::shared_ptr<YoYInflationIndex>& yii,
                                       CPI::InterpolationType interpolation,
                                       Handle<YieldTermStructure> nominalTermStructure);
 
@@ -94,18 +103,24 @@ namespace QuantLib {
         */
         [[deprecated("Use the overload that passes an interpolation type instead")]]
         YearOnYearInflationSwapHelper(const Handle<Quote>& quote,
-                                      const Period& swapObsLag_,
+                                      const Period& swapObsLag,
                                       const Date& maturity,
                                       Calendar calendar,
                                       BusinessDayConvention paymentConvention,
                                       DayCounter dayCounter,
-                                      ext::shared_ptr<YoYInflationIndex> yii,
+                                      const ext::shared_ptr<YoYInflationIndex>& yii,
                                       Handle<YieldTermStructure> nominalTermStructure);
 
         void setTermStructure(YoYInflationTermStructure*) override;
         Real impliedQuote() const override;
-
+        //! \name inspectors
+        //@{
+        // NOLINTNEXTLINE(cppcoreguidelines-noexcept-swap,performance-noexcept-swap)
+        ext::shared_ptr<YearOnYearInflationSwap> swap() const { return yyiis_; }
+        //@}
       protected:
+        void initializeDates() override;
+
         Period swapObsLag_;
         Date maturity_;
         Calendar calendar_;
@@ -115,6 +130,7 @@ namespace QuantLib {
         CPI::InterpolationType interpolation_;
         ext::shared_ptr<YearOnYearInflationSwap> yyiis_;
         Handle<YieldTermStructure> nominalTermStructure_;
+        RelinkableHandle<YoYInflationTermStructure> termStructureHandle_;
     };
 
 }
