@@ -13,7 +13,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -28,7 +28,6 @@
 #define quantlib_iterative_bootstrap_hpp
 
 #include <ql/termstructures/bootstraphelper.hpp>
-#include <ql/termstructures/bootstraperror.hpp>
 #include <ql/math/interpolations/linearinterpolation.hpp>
 #include <ql/math/solvers1d/finitedifferencenewtonsafe.hpp>
 #include <ql/math/solvers1d/brent.hpp>
@@ -42,9 +41,8 @@ namespace detail {
         searching for a helper root between \c xMin and \c xMax, we use this function to return the value that
         gives the minimum absolute helper error in the interval between \c xMin and \c xMax inclusive.
     */
-    template <class Curve>
-    Real dontThrowFallback(const BootstrapError<Curve>& error,
-        Real xMin, Real xMax, Size steps) {
+    template <class Fn>
+    Real dontThrowFallback(const Fn& error, Real xMin, Real xMax, Size steps) {
 
         QL_REQUIRE(xMin < xMax, "Expected xMin to be less than xMax");
 
@@ -99,7 +97,8 @@ namespace detail {
                            Real maxFactor = 2.0,
                            Real minFactor = 2.0,
                            bool dontThrow = false,
-                           Size dontThrowSteps = 10);
+                           Size dontThrowSteps = 10,
+                           Size maxEvaluations = MAX_FUNCTION_EVALUATIONS);
         void setup(Curve* ts);
         void calculate() const;
       private:
@@ -117,8 +116,6 @@ namespace detail {
         FiniteDifferenceNewtonSafe solver_;
         mutable bool initialized_ = false, validCurve_ = false, loopRequired_;
         mutable Size firstAliveHelper_ = 0, alive_ = 0;
-        mutable std::vector<Real> previousData_;
-        mutable std::vector<ext::shared_ptr<BootstrapError<Curve> > > errors_;
     };
 
 
@@ -132,12 +129,15 @@ namespace detail {
                                                   Real maxFactor,
                                                   Real minFactor,
                                                   bool dontThrow,
-                                                  Size dontThrowSteps)
+                                                  Size dontThrowSteps,
+                                                  Size maxEvaluations)
     : accuracy_(accuracy), minValue_(minValue), maxValue_(maxValue), maxAttempts_(maxAttempts),
       maxFactor_(maxFactor), minFactor_(minFactor), dontThrow_(dontThrow),
       dontThrowSteps_(dontThrowSteps), ts_(nullptr), loopRequired_(Interpolator::global) {
         QL_REQUIRE(maxFactor_ >= 1.0, "Expected that maxFactor would be at least 1.0 but got " << maxFactor_);
         QL_REQUIRE(minFactor_ >= 1.0, "Expected that minFactor would be at least 1.0 but got " << minFactor_);
+        firstSolver_.setMaxEvaluations(maxEvaluations);
+        solver_.setMaxEvaluations(maxEvaluations);
     }
 
     template <class Curve>
@@ -146,7 +146,7 @@ namespace detail {
         n_ = ts_->instruments_.size();
         QL_REQUIRE(n_ > 0, "no bootstrap helpers given");
         for (Size j=0; j<n_; ++j)
-            ts_->registerWith(ts_->instruments_[j]);
+            ts_->registerWithObservables(ts_->instruments_[j]);
 
         // do not initialize yet: instruments could be invalid here
         // but valid later when bootstrapping is actually required
@@ -171,28 +171,26 @@ namespace detail {
                    " provided, " << Interpolator::requiredPoints-1 <<
                    " required");
 
-        // calculate dates and times, create errors_
+        // calculate dates and times
         std::vector<Date>& dates = ts_->dates_;
         std::vector<Time>& times = ts_->times_;
         dates.resize(alive_+1);
         times.resize(alive_+1);
-        errors_.resize(alive_+1);
         dates[0] = firstDate;
         times[0] = ts_->timeFromReference(dates[0]);
 
-        Date latestRelevantDate, maxDate = firstDate;
+        Date maxDate = firstDate;
         // pillar counter: i
         // helper counter: j
         for (Size i=1, j=firstAliveHelper_; j<n_; ++i, ++j) {
-            const ext::shared_ptr<typename Traits::helper>& helper =
-                                                        ts_->instruments_[j];
+            const auto& helper = ts_->instruments_[j];
             dates[i] = helper->pillarDate();
             times[i] = ts_->timeFromReference(dates[i]);
             // check for duplicated pillars
             QL_REQUIRE(dates[i-1]!=dates[i],
                        "more than one instrument with pillar " << dates[i]);
 
-            latestRelevantDate = helper->latestRelevantDate();
+            Date latestRelevantDate = helper->latestRelevantDate();
             // check that the helper is really extending the curve, i.e. that
             // pillar-sorted helpers are also sorted by latestRelevantDate
             QL_REQUIRE(latestRelevantDate > maxDate,
@@ -201,15 +199,12 @@ namespace detail {
                        latestRelevantDate << ") before or equal to "
                        "previous instrument's latestRelevantDate (" <<
                        maxDate << ")");
-            maxDate = latestRelevantDate;
+            maxDate = std::max(dates[i], latestRelevantDate);
 
-            // when a pillar date is different from the last relevant date the
+            // when a pillar date is before the last relevant date the
             // convergence loop is required even if the Interpolator is local
-            if (dates[i] != latestRelevantDate)
+            if (dates[i] < latestRelevantDate)
                 loopRequired_ = true;
-
-            errors_[i] = ext::shared_ptr<BootstrapError<Curve> >(new
-                BootstrapError<Curve>(ts_, helper, i));
         }
         ts_->maxDate_ = maxDate;
 
@@ -219,7 +214,6 @@ namespace detail {
             // but reasonable numbers might be needed for the whole data vector
             // because, e.g., of interpolation's early checks
             ts_->data_ = std::vector<Real>(alive_+1, Traits::initialValue(ts_));
-            previousData_.resize(alive_+1);
             validCurve_ = false;
         }
         initialized_ = true;
@@ -238,8 +232,7 @@ namespace detail {
 
         // setup helpers
         for (Size j=firstAliveHelper_; j<n_; ++j) {
-            const ext::shared_ptr<typename Traits::helper>& helper =
-                                                        ts_->instruments_[j];
+            const auto& helper = ts_->instruments_[j];
             // check for valid quote
             QL_REQUIRE(helper->quote()->isValid(),
                        io::ordinal(j + 1) << " instrument (maturity: " <<
@@ -259,16 +252,18 @@ namespace detail {
 
         // there might be a valid curve state to use as guess
         bool validData = validCurve_;
+        std::vector<Real> previousData;
 
         for (Size iteration=0; ; ++iteration) {
-            previousData_ = ts_->data_;
+            if (loopRequired_ && validData)
+                previousData = ts_->data_;
 
             // Store min value and max value at each pillar so that we can expand search if necessary.
             std::vector<Real> minValues(alive_+1, Null<Real>());
             std::vector<Real> maxValues(alive_+1, Null<Real>());
             std::vector<Size> attempts(alive_+1, 1);
 
-            for (Size i=1; i<=alive_; ++i) { // pillar loop
+            for (Size i=1, j=firstAliveHelper_; j<n_; ++i, ++j) { // pillar loop
 
                 // shorter aliases for readability and to avoid duplication
                 Real& min = minValues[i];
@@ -315,11 +310,17 @@ namespace detail {
                     ts_->interpolation_.update();
                 }
 
+                const auto& helper = ts_->instruments_[j];
+                auto error = [&](Rate guess) {
+                    Traits::updateGuess(ts_->data_, guess, i);
+                    ts_->interpolation_.update();
+                    return helper->quoteError();
+                };
                 try {
                     if (validData)
-                        solver_.solve(*errors_[i], accuracy, guess, min, max);
+                        solver_.solve(error, accuracy, guess, min, max);
                     else
-                        firstSolver_.solve(*errors_[i], accuracy, guess, min, max);
+                        firstSolver_.solve(error, accuracy, guess, min, max);
                 } catch (std::exception &e) {
                     if (validCurve_) {
                         // the previous curve state might have been a
@@ -338,12 +339,13 @@ namespace detail {
                     if (attempts[i] < maxAttempts_) {
                         attempts[i]++;
                         i--;
+                        j--;
                         continue;
                     }
 
                     if (dontThrow_) {
                         // Use the fallback value
-                        ts_->data_[i] = detail::dontThrowFallback(*errors_[i], min, max, dontThrowSteps_);
+                        ts_->data_[i] = detail::dontThrowFallback(error, min, max, dontThrowSteps_);
 
                         // Remember to update the interpolation. If we don't and we are on the last "i", we will still
                         // have the last attempted value in the solver being used in ts_->interpolation_.
@@ -351,8 +353,8 @@ namespace detail {
                     } else {
                         QL_FAIL(io::ordinal(iteration + 1) << " iteration: failed "
                                 "at " << io::ordinal(i) << " alive instrument, "
-                                "pillar " << errors_[i]->helper()->pillarDate() <<
-                                ", maturity " << errors_[i]->helper()->maturityDate() <<
+                                "pillar " << helper->pillarDate() <<
+                                ", maturity " << helper->maturityDate() <<
                                 ", reference date " << ts_->dates_[0] <<
                                 ": " << e.what());
                     }
@@ -363,11 +365,13 @@ namespace detail {
                  break;
 
             // exit condition
-            Real change = std::fabs(data[1]-previousData_[1]);
-            for (Size i=2; i<=alive_; ++i)
-                change = std::max(change, std::fabs(data[i]-previousData_[i]));
-            if (change<=accuracy)  // convergence reached
-                break;
+            Real change = 0;
+            if (validData) {
+                for (Size i=1; i<=alive_; ++i)
+                    change = std::max(change, std::fabs(data[i]-previousData[i]));
+                if (change<=accuracy)  // convergence reached
+                    break;
+            }
 
             // If we hit the max number of iterations and dontThrow is true, just use what we have
             if (iteration == maxIterations) {
