@@ -12,7 +12,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -78,8 +78,6 @@ namespace QuantLib {
     }
 
 
-    QL_DEPRECATED_DISABLE_WARNING
-
     FixedRateBondHelper::FixedRateBondHelper(
                                     const Handle<Quote>& price,
                                     Natural settlementDays,
@@ -104,8 +102,6 @@ namespace QuantLib {
                                                  exCouponConvention, exCouponEndOfMonth),
                  priceType) {}
 
-    QL_DEPRECATED_ENABLE_WARNING
-
     void FixedRateBondHelper::accept(AcyclicVisitor& v) {
         auto* v1 = dynamic_cast<Visitor<FixedRateBondHelper>*>(&v);
         if (v1 != nullptr)
@@ -117,6 +113,31 @@ namespace QuantLib {
 
     QL_DEPRECATED_DISABLE_WARNING
 
+    CPIBondHelper::CPIBondHelper(
+                            const Handle<Quote>& price,
+                            Natural settlementDays,
+                            Real faceAmount,
+                            Real baseCPI,
+                            const Period& observationLag,
+                            const ext::shared_ptr<ZeroInflationIndex>& cpiIndex,
+                            CPI::InterpolationType observationInterpolation,
+                            Schedule schedule,
+                            const std::vector<Rate>& fixedRate,
+                            const DayCounter& accrualDayCounter,
+                            BusinessDayConvention paymentConvention,
+                            const Date& issueDate,
+                            const Calendar& paymentCalendar,
+                            const Period& exCouponPeriod,
+                            const Calendar& exCouponCalendar,
+                            const BusinessDayConvention exCouponConvention,
+                            bool exCouponEndOfMonth,
+                            const Bond::Price::Type priceType)
+    : CPIBondHelper(price, settlementDays, faceAmount, false, baseCPI, observationLag,
+                    cpiIndex, observationInterpolation, std::move(schedule), fixedRate,
+                    accrualDayCounter, paymentConvention, issueDate, paymentCalendar,
+                    exCouponPeriod, exCouponCalendar, exCouponConvention, exCouponEndOfMonth,
+                    priceType) {}
+
     CPIBondHelper::CPIBondHelper(
                             const Handle<Quote>& price,
                             Natural settlementDays,
@@ -138,11 +159,12 @@ namespace QuantLib {
                             bool exCouponEndOfMonth,
                             const Bond::Price::Type priceType)
     : BondHelper(price,
-                 ext::make_shared<CPIBond>(settlementDays, faceAmount, growthOnly, baseCPI,
+                 // make_shared and deprecation interfere; restore later
+                 ext::shared_ptr<Bond>(new CPIBond(settlementDays, faceAmount, growthOnly, baseCPI,
                                            observationLag, cpiIndex, observationInterpolation,
                                            std::move(schedule), fixedRate, accrualDayCounter, paymentConvention,
                                            issueDate, paymentCalendar, exCouponPeriod, exCouponCalendar,
-                                           exCouponConvention, exCouponEndOfMonth),
+                                           exCouponConvention, exCouponEndOfMonth)),
                  priceType) {}
 
     QL_DEPRECATED_ENABLE_WARNING
