@@ -11,7 +11,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -28,6 +28,7 @@
 #include <ql/termstructures/yield/ratehelpers.hpp>
 #include <ql/instruments/overnightindexedswap.hpp>
 #include <ql/optional.hpp>
+#include <variant>
 
 namespace QuantLib {
 
@@ -36,53 +37,61 @@ namespace QuantLib {
     //! Rate helper for bootstrapping over Overnight Indexed Swap rates
     class OISRateHelper : public RelativeDateRateHelper {
       public:
-        OISRateHelper(Natural settlementDays,
-                      const Period& tenor, // swap maturity
-                      const Handle<Quote>& fixedRate,
-                      const ext::shared_ptr<OvernightIndex>& overnightIndex,
-                      // exogenous discounting curve
-                      Handle<YieldTermStructure> discountingCurve = {},
-                      bool telescopicValueDates = false,
-                      Integer paymentLag = 0,
-                      BusinessDayConvention paymentConvention = Following,
-                      Frequency paymentFrequency = Annual,
-                      Calendar paymentCalendar = Calendar(),
-                      const Period& forwardStart = 0 * Days,
-                      Spread overnightSpread = 0.0,
-                      Pillar::Choice pillar = Pillar::LastRelevantDate,
-                      Date customPillarDate = Date(),
-                      RateAveraging::Type averagingMethod = RateAveraging::Compound,
-                      ext::optional<bool> endOfMonth = ext::nullopt,
-                      ext::optional<Frequency> fixedPaymentFrequency = ext::nullopt,
-                      Calendar fixedCalendar = Calendar(),
-                      Natural lookbackDays = Null<Natural>(),
-                      Natural lockoutDays = 0,
-                      bool applyObservationShift = false,
-                      ext::shared_ptr<FloatingRateCouponPricer> pricer = {},
-                      DateGeneration::Rule rule = DateGeneration::Backward);
-        OISRateHelper(const Date& startDate,
-                      const Date& endDate,
-                      const Handle<Quote>& fixedRate,
-                      const ext::shared_ptr<OvernightIndex>& overnightIndex,
-                      // exogenous discounting curve
-                      Handle<YieldTermStructure> discountingCurve = {},
-                      bool telescopicValueDates = false,
-                      Integer paymentLag = 0,
-                      BusinessDayConvention paymentConvention = Following,
-                      Frequency paymentFrequency = Annual,
-                      Calendar paymentCalendar = Calendar(),
-                      Spread overnightSpread = 0.0,
-                      Pillar::Choice pillar = Pillar::LastRelevantDate,
-                      Date customPillarDate = Date(),
-                      RateAveraging::Type averagingMethod = RateAveraging::Compound,
-                      ext::optional<bool> endOfMonth = ext::nullopt,
-                      ext::optional<Frequency> fixedPaymentFrequency = ext::nullopt,
-                      Calendar fixedCalendar = Calendar(),
-                      Natural lookbackDays = Null<Natural>(),
-                      Natural lockoutDays = 0,
-                      bool applyObservationShift = false,
-                      ext::shared_ptr<FloatingRateCouponPricer> pricer = {},
-                      DateGeneration::Rule rule = DateGeneration::Backward);
+        OISRateHelper(
+          Natural settlementDays,
+          const Period& tenor, // swap maturity
+          const std::variant<Rate, Handle<Quote>>& fixedRate,
+          const ext::shared_ptr<OvernightIndex>& overnightIndex,
+          // exogenous discounting curve
+          Handle<YieldTermStructure> discountingCurve = {},
+          bool telescopicValueDates = false,
+          Integer paymentLag = 0,
+          BusinessDayConvention paymentConvention = Following,
+          Frequency paymentFrequency = Annual,
+          Calendar paymentCalendar = Calendar(),
+          const Period& forwardStart = 0 * Days,
+          const std::variant<Spread, Handle<Quote>>& overnightSpread = Spread(0.0),
+          Pillar::Choice pillar = Pillar::LastRelevantDate,
+          Date customPillarDate = Date(),
+          RateAveraging::Type averagingMethod = RateAveraging::Compound,
+          ext::optional<bool> endOfMonth = ext::nullopt,
+          ext::optional<Frequency> fixedPaymentFrequency = ext::nullopt,
+          Calendar fixedCalendar = Calendar(),
+          Natural lookbackDays = Null<Natural>(),
+          Natural lockoutDays = 0,
+          bool applyObservationShift = false,
+          ext::shared_ptr<FloatingRateCouponPricer> pricer = {},
+          DateGeneration::Rule rule = DateGeneration::Backward,
+          Calendar overnightCalendar = Calendar(),
+          BusinessDayConvention convention = ModifiedFollowing);
+
+        OISRateHelper(
+          const Date& startDate,
+          const Date& endDate,
+          const std::variant<Rate, Handle<Quote>>& fixedRate,
+          const ext::shared_ptr<OvernightIndex>& overnightIndex,
+          // exogenous discounting curve
+          Handle<YieldTermStructure> discountingCurve = {},
+          bool telescopicValueDates = false,
+          Integer paymentLag = 0,
+          BusinessDayConvention paymentConvention = Following,
+          Frequency paymentFrequency = Annual,
+          Calendar paymentCalendar = Calendar(),
+          const std::variant<Spread, Handle<Quote>>& overnightSpread = Spread(0.0),
+          Pillar::Choice pillar = Pillar::LastRelevantDate,
+          Date customPillarDate = Date(),
+          RateAveraging::Type averagingMethod = RateAveraging::Compound,
+          ext::optional<bool> endOfMonth = ext::nullopt,
+          ext::optional<Frequency> fixedPaymentFrequency = ext::nullopt,
+          Calendar fixedCalendar = Calendar(),
+          Natural lookbackDays = Null<Natural>(),
+          Natural lockoutDays = 0,
+          bool applyObservationShift = false,
+          ext::shared_ptr<FloatingRateCouponPricer> pricer = {},
+          DateGeneration::Rule rule = DateGeneration::Backward,
+          Calendar overnightCalendar = Calendar(),
+          BusinessDayConvention convention = ModifiedFollowing);
+
         //! \name RateHelper interface
         //@{
         Real impliedQuote() const override;
@@ -119,12 +128,14 @@ namespace QuantLib {
         Frequency paymentFrequency_;
         Calendar paymentCalendar_;
         Period forwardStart_;
-        Spread overnightSpread_;
+        Handle<Quote> overnightSpread_;
         Pillar::Choice pillarChoice_;
         RateAveraging::Type averagingMethod_;
         ext::optional<bool> endOfMonth_;
         ext::optional<Frequency> fixedPaymentFrequency_;
         Calendar fixedCalendar_;
+        Calendar overnightCalendar_;
+        BusinessDayConvention convention_;
         Natural lookbackDays_;
         Natural lockoutDays_;
         bool applyObservationShift_;
@@ -150,7 +161,7 @@ namespace QuantLib {
                            BusinessDayConvention paymentConvention = Following,
                            Frequency paymentFrequency = Annual,
                            const Calendar& paymentCalendar = Calendar(),
-                           Spread overnightSpread = 0.0,
+                           Spread overnightSpread = {},
                            ext::optional<bool> endOfMonth = ext::nullopt,
                            ext::optional<Frequency> fixedPaymentFrequency = ext::nullopt,
                            const Calendar& fixedCalendar = Calendar(),
@@ -158,28 +169,6 @@ namespace QuantLib {
                            Natural lockoutDays = 0,
                            bool applyObservationShift = false,
                            const ext::shared_ptr<FloatingRateCouponPricer>& pricer = {});
-
-        /*! \deprecated Use the overload without forward start.
-                        Deprecated in version 1.35.
-        */
-        [[deprecated("Use the overload without forward start")]]
-        DatedOISRateHelper(const Date& startDate,
-                           const Date& endDate,
-                           const Handle<Quote>& fixedRate,
-                           const ext::shared_ptr<OvernightIndex>& overnightIndex,
-                           // exogenous discounting curve
-                           Handle<YieldTermStructure> discountingCurve,
-                           bool telescopicValueDates,
-                           RateAveraging::Type averagingMethod,
-                           Integer paymentLag,
-                           BusinessDayConvention paymentConvention,
-                           Frequency paymentFrequency,
-                           const Calendar& paymentCalendar,
-                           const Period& forwardStart,
-                           Spread overnightSpread = 0.0,
-                           ext::optional<bool> endOfMonth = ext::nullopt,
-                           ext::optional<Frequency> fixedPaymentFrequency = ext::nullopt,
-                           const Calendar& fixedCalendar = Calendar());
     };
 
 }
