@@ -11,7 +11,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -25,8 +25,9 @@
 #ifndef quantlib_zero_spreaded_term_structure_hpp
 #define quantlib_zero_spreaded_term_structure_hpp
 
-#include <ql/termstructures/yield/zeroyieldstructure.hpp>
 #include <ql/quote.hpp>
+#include <ql/termstructures/yield/zeroyieldstructure.hpp>
+#include <utility>
 
 namespace QuantLib {
 
@@ -45,27 +46,27 @@ namespace QuantLib {
     */
     class ZeroSpreadedTermStructure : public ZeroYieldStructure {
       public:
-        ZeroSpreadedTermStructure(const Handle<YieldTermStructure>&,
-                                  const Handle<Quote>& spread,
+        ZeroSpreadedTermStructure(Handle<YieldTermStructure>,
+                                  Handle<Quote> spread,
                                   Compounding comp = Continuous,
                                   Frequency freq = NoFrequency,
-                                  const DayCounter& dc = DayCounter());
+                                  DayCounter dc = DayCounter());
         //! \name YieldTermStructure interface
         //@{
-        DayCounter dayCounter() const;
-        Calendar calendar() const;
-        Natural settlementDays() const;
-        const Date& referenceDate() const;
-        Date maxDate() const;
-        Time maxTime() const;
+        DayCounter dayCounter() const override;
+        Calendar calendar() const override;
+        Natural settlementDays() const override;
+        const Date& referenceDate() const override;
+        Date maxDate() const override;
+        Time maxTime() const override;
         //@}
         //! \name Observer interface
         //@{
-        void update();
+        void update() override;
         //@}
       protected:
         //! returns the spreaded zero yield rate
-        Rate zeroYieldImpl(Time) const;
+        Rate zeroYieldImpl(Time) const override;
         //! returns the spreaded forward rate
         /* This method must disappear should the spread become a curve */
         Rate forwardImpl(Time) const;
@@ -77,13 +78,13 @@ namespace QuantLib {
         DayCounter dc_;
     };
 
-    inline ZeroSpreadedTermStructure::ZeroSpreadedTermStructure(
-                                          const Handle<YieldTermStructure>& h,
-                                          const Handle<Quote>& spread,
-                                          Compounding comp,
-                                          Frequency freq,
-                                          const DayCounter& dc)
-    : originalCurve_(h), spread_(spread), comp_(comp), freq_(freq), dc_(dc) {
+    inline ZeroSpreadedTermStructure::ZeroSpreadedTermStructure(Handle<YieldTermStructure> h,
+                                                                Handle<Quote> spread,
+                                                                Compounding comp,
+                                                                Frequency freq,
+                                                                DayCounter dc)
+    : originalCurve_(std::move(h)), spread_(std::move(spread)), comp_(comp), freq_(freq),
+      dc_(std::move(dc)) {
         if (!originalCurve_.empty())
             enableExtrapolation(originalCurve_->allowsExtrapolation());
         registerWith(originalCurve_);
