@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -51,16 +51,23 @@ namespace QuantLib {
     */
     class Australia : public Calendar {
       private:
-        class Impl : public Calendar::WesternImpl {
+        class SettlementImpl final : public Calendar::WesternImpl {
           public:
-            std::string name() const override { return "Australia"; }
+            std::string name() const override { return "Australia settlement"; }
+            bool isBusinessDay(const Date&) const override;
+        };
+        class AsxImpl final : public Calendar::WesternImpl {
+          public:
+            std::string name() const override { return "Australia exchange"; }
             bool isBusinessDay(const Date&) const override;
         };
       public:
-        Australia();
+        enum Market { Settlement,     //!< generic settlement calendar
+                      ASX,       //!< Australia ASX calendar
+        };
+        Australia(Market market = Settlement);
     };
 
 }
 
-
-#endif
+#endif
\ No newline at end of file
