@@ -11,7 +11,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -57,14 +57,14 @@ namespace QuantLib {
     */
     class China : public Calendar {
       private:
-        class SseImpl : public Calendar::Impl {
+        class SseImpl final : public Calendar::Impl {
           public:
             std::string name() const override { return "Shanghai stock exchange"; }
             bool isWeekend(Weekday) const override;
             bool isBusinessDay(const Date&) const override;
         };
 
-        class IbImpl : public Calendar::Impl {
+        class IbImpl final : public Calendar::Impl {
           public:
             IbImpl()
             : sseImpl(ext::make_shared<China::SseImpl>()) {}
