@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -50,10 +50,10 @@ namespace QuantLib {
     */
     class Hungary : public Calendar {
       private:
-        class Impl : public Calendar::WesternImpl {
+        class Impl final : public Calendar::WesternImpl {
           public:
-            std::string name() const { return "Hungary"; }
-            bool isBusinessDay(const Date&) const;
+            std::string name() const override { return "Hungary"; }
+            bool isBusinessDay(const Date&) const override;
         };
       public:
         Hungary();
