@@ -2,6 +2,7 @@
 
 /*
  Copyright (C) 2005, 2007, 2008, 2009, 2010, 2011 StatPro Italia srl
+ Copyright (C) 2023, 2024 Skandinaviska Enskilda Banken AB (publ)
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -10,7 +11,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -347,7 +348,144 @@ namespace QuantLib {
               return false;
       }
 
-        return true;
+        if (y == 2021) {
+            if (// Chatrapati Shivaji Jayanti
+                (d == 19 && m == February)
+                // Mahashivratri
+                || (d == 11 && m == March)
+                // Holi
+                || (d == 29 && m == March) 
+                // Gudi Padwa
+                || (d == 13 && m == April)
+                // Mahavir Jayanti
+                || (d == 14 && m == April)
+                // Ram Navami
+                || (d == 21 && m == April)
+                // Buddha Pournima
+                || (d == 26 && m == May)
+                // Bakri Id
+                || (d == 21 && m == July)
+                // Ganesh Chaturthi
+                || (d == 10 && m == September)
+                // Dasera
+                || (d == 15 && m == October)
+                // Id-E-Milad
+                || (d == 19 && m == October)
+                // Diwali - Balipratipada
+                || (d == 5 && m == November)
+                // Gurunank Jayanti
+                || (d == 19 && m == November))
+                return false;
+        }
+
+        if (y == 2022) {
+            if ( // Mahashivratri
+                (d == 1 && m == March)
+                // Holi
+                || (d == 18 && m == March)
+                // Ramzan Id
+                || (d == 3 && m == May)
+                // Buddha Pournima
+                || (d == 16 && m == May)
+                // Ganesh Chaturthi
+                || (d == 31 && m == August)
+                // Dasera
+                || (d == 5 && m == October)
+                // Diwali - Balipratipada
+                || (d == 26 && m == October)
+                // Gurunank Jayanti
+                || (d == 8 && m == November))
+                return false;
+        }
+
+        if (y == 2023) {
+            if ( 
+                // Holi
+                (d == 7 && m == March)
+                // Gudi Padwa
+                || (d == 22 && m == March)
+                // Ram Navami
+                || (d == 30 && m == March)
+                // Mahavir Jayanti
+                || (d == 4 && m == April)
+                // Buddha Pournima
+                || (d == 5 && m == May)
+                // Bakri Id
+                || (d == 29 && m == June)
+                // Parsi New year
+                || (d == 16 && m == August)
+                // Ganesh Chaturthi
+                || (d == 19 && m == September)
+                // Id-E-Milad (was moved to Friday 29th)
+                || (d == 29 && m == September)
+                // Dasera
+                || (d == 24 && m == October)
+                // Diwali - Balipratipada
+                || (d == 14 && m == November)
+                // Gurunank Jayanti
+                || (d == 27 && m == November))
+                return false;
+        }
+
+        if (y == 2024) {
+            if ( // Special holiday
+                (d == 22 && m == January)
+                // Chatrapati Shivaji Jayanti
+                || (d == 19 && m == February)
+                // Mahashivratri
+                || (d == 8 && m == March)
+                // Holi
+                || (d == 25 && m == March)
+                // Annual Bank Closing
+                || (d == 1 && m == April)
+                // Gudi Padwa
+                || (d == 9 && m == April)
+                // Id-Ul-Fitr (Ramadan Eid)
+                || (d == 11 && m == April)
+                // Ram Navami
+                || (d == 17 && m == April)
+                // Mahavir Jayanti
+                || (d == 21 && m == April)
+                // General Parliamentary Elections
+                || (d == 20 && m == May)
+                // Buddha Pournima
+                || (d == 23 && m == May)
+                // Bakri Eid
+                || (d == 17 && m == June)
+                // Moharram
+                || (d == 17 && m == July)
+                // Eid-E-Milad (estimated Sunday 15th or Monday 16th)
+                || (d == 16 && m == September)
+                // Diwali-Laxmi Pujan
+                || (d == 1 && m == November)
+                // Gurunank Jayanti
+                || (d == 15 && m == November))
+                return false;
+        }
+
+        if (y == 2025) {
+            if ( // Chatrapati Shivaji Jayanti
+                (d == 19 && m == February)
+                // Mahashivratri
+                || (d == 26 && m == February)
+                // Holi
+                || (d == 14 && m == March)
+                // Ramzan Id (estimated Sunday 30th or Monday 31st)
+                || (d == 31  && m == March)
+                // Mahavir Jayanti
+                || (d == 10 && m == April)
+                // Buddha Pournima
+                || (d == 12 && m == May)
+                // Id-E-Milad (estimated Thursday 4th or Friday 5th)
+                || (d == 5 && m == September)
+                // Diwali - Balipratipada
+                || (d == 22 && m == October)
+                // Gurunank Jayanti
+                || (d == 5 && m == November))
+                return false;
+        }
+
+     return true;
     }
 
 }
