@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -57,15 +57,15 @@ namespace QuantLib {
     */
     class Russia : public Calendar {
       private:
-        class SettlementImpl : public Calendar::OrthodoxImpl {
+        class SettlementImpl final : public Calendar::OrthodoxImpl {
           public:
-            std::string name() const { return "Russian settlement"; }
-            bool isBusinessDay(const Date&) const;
+            std::string name() const override { return "Russian settlement"; }
+            bool isBusinessDay(const Date&) const override;
         };
-        class ExchangeImpl : public Calendar::OrthodoxImpl {
+        class ExchangeImpl final : public Calendar::OrthodoxImpl {
           public:
-            std::string name() const { return "Moscow exchange"; }
-            bool isBusinessDay(const Date&) const;
+            std::string name() const override { return "Moscow exchange"; }
+            bool isBusinessDay(const Date&) const override;
         };
       public:
         //! Russian calendars
