@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -87,12 +87,10 @@ namespace QuantLib {
             Time
             yearFraction(const Date& d1, const Date& d2, const Date&, const Date&) const override;
         };
-        static ext::shared_ptr<DayCounter::Impl> implementation(Convention c, 
-                                                                const Schedule& schedule);
+        static ext::shared_ptr<DayCounter::Impl> implementation(Convention c, Schedule schedule);
       public:
-        explicit ActualActual(Convention c,
-                              const Schedule& schedule = Schedule())
-        : DayCounter(implementation(c, schedule)) {}
+        explicit ActualActual(Convention c, Schedule schedule = Schedule())
+        : DayCounter(implementation(c, std::move(schedule))) {}
     };
 
 }
