@@ -14,7 +14,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -422,6 +422,12 @@ namespace QuantLib {
                                  const short_period_holder& holder) {
             Integer n = holder.p.length();
             switch (holder.p.units()) {
+              case Hours:
+                return out << n << "h";
+              case Minutes:
+                return out << n << "m";
+              case Seconds:
+                return out << n << "s";
               case Days:
                 return out << n << "D";
               case Weeks:
