@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -50,14 +50,15 @@ namespace QuantLib {
         T& operator*() const;
         T* operator->() const;
         bool empty() const;
-        void swap(Clone<T>& t);
+        void swap(Clone<T>& t) noexcept;
+        ~Clone() = default;
       private:
         std::unique_ptr<T> ptr_;
     };
 
     /*! \relates Clone */
     template <class T>
-    void swap(Clone<T>&, Clone<T>&);
+    void swap(Clone<T>&, Clone<T>&) noexcept;
 
 
     // inline definitions
@@ -114,12 +115,12 @@ namespace QuantLib {
     }
 
     template <class T>
-    inline void Clone<T>::swap(Clone<T>& t) {
+    inline void Clone<T>::swap(Clone<T>& t) noexcept {
         this->ptr_.swap(t.ptr_);
     }
 
     template <class T>
-    inline void swap(Clone<T>& t, Clone<T>& u) {
+    inline void swap(Clone<T>& t, Clone<T>& u) noexcept {
         t.swap(u);
     }
 
