@@ -11,7 +11,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -50,7 +50,7 @@
 #include <ql/indexes/ibor/corra.hpp>
 #include <ql/indexes/ibor/tibor.hpp>
 #include <ql/indexes/ibor/aonia.hpp>
-#include <ql/indexes/ibor/tona.hpp>
+#include <ql/indexes/ibor/tonar.hpp>
 #include <ql/indexes/ibor/saron.hpp>
 #include <ql/indexes/ibor/nzocr.hpp>
 #include <ql/indexes/ibor/destr.hpp>
@@ -996,7 +996,7 @@ BOOST_AUTO_TEST_CASE(testMakeOISDefaultSettlementDays) {
         {"FedFunds", ext::make_shared<FedFunds>()},
         {"SOFR", ext::make_shared<Sofr>()},
         {"AONIA", ext::make_shared<Aonia>()},
-        {"TONA", ext::make_shared<Tona>()},
+        {"TONAR", ext::make_shared<Tonar>()},
         {"SARON", ext::make_shared<Saron>()},
         {"NZOCR", ext::make_shared<Nzocr>()},
         {"DESTR", ext::make_shared<Destr>()},
